@@ -1,4 +1,5 @@
 """Implement matrix based fwt and ifwt.
+This module uses boundary filters instead of padding.
 
 The implementation is based on the description
 in Strang Nguyen (p. 32), as well as the description
@@ -16,20 +17,23 @@ from .sparse_math import (
 from .conv_transform import get_filter_tensors
 
 
-def cat_sparse_identity_matrix(sparse_matrix, new_length):
+def cat_sparse_identity_matrix(
+        sparse_matrix: torch.Tensor, new_length: int) -> torch.Tensor:
     """Concatenate a sparse input matrix and a sparse identity matrix.
 
     Args:
-        sparse_matrix: The input matrix.
-        new_length: The length up to which the diagonal should be elongated.
+        sparse_matrix (torch.Tensor): The input matrix.
+        new_length (int):
+            The length up to which the diagonal should be elongated.
 
     Returns:
-        Square [input, eye] matrix of size [new_length, new_length]
+        torch.Tensor: Square [input, eye] matrix
+            of size [new_length, new_length]
     """
     # assert square matrix.
     assert (
         sparse_matrix.shape[0] == sparse_matrix.shape[1]
-    ), "wavelet matrices are square"
+    ), "Input matrices must be square. Odd inputs lead to non-square matrices."
     assert new_length > sparse_matrix.shape[0],\
         "cant add negatively many entries."
     x = torch.arange(sparse_matrix.shape[0], new_length,
@@ -194,11 +198,16 @@ class MatrixWavedec(object):
     def __call__(self, data) -> list:
         """Compute the matrix fwt.
 
+        Matrix fwt are used to avoid padding.
+        Intermediate scale results must be divisible
+        by two. A working third level transform
+        could use and input length of 128.
+        This would lead to intermediate resolutions
+        of 64 and 32.
+
         Args:
             data: Batched input data [batch_size, time],
                   should be of even length.
-                  WARNING: If the input length is odd it will be padded on the
-                  right to make it even.
 
         Returns:
             list: A list with the coefficients for each scale.
