@@ -1,6 +1,8 @@
-"""Two dimensional matrix based fast wavelet transform implementations."""
+"""Two dimensional matrix based fast wavelet transform implementations.
+This module uses boundary filters instead of padding.
+"""
 # Written by moritz ( @ wolter.tech ) in 2021
-
+import pywt
 import torch
 import numpy as np
 
@@ -16,20 +18,20 @@ from .matmul_transform import (
 )
 
 
-def _construct_a_2d(wavelet, height: int, width: int,
-                    device: torch.device, dtype=torch.float64) -> torch.tensor:
+def _construct_a_2d(wavelet: pywt.Wavelet, height: int, width: int,
+                    device: torch.device, dtype: torch.dtype=torch.float64) -> torch.tensor:
     """Construct a raw two dimensional analysis wavelet transformation matrix.
 
     Args:
         wavelet (pywt.Wavelet): The wavelet to use.
         height (int): The Height of the input image.
-        width (int): The Widht of the input image.
-        device ([torch.device]): Where to place to matrix, either cpu or gpu.
-        dtype ([type], optional): Desired matrix data-type.
+        width (int): The Width of the input image.
+        device (torch.device): Where to place to matrix, either cpu or gpu.
+        dtype (torch.dtype, optional): Desired matrix data-type.
             Defaults to torch.float64.
 
     Returns:
-        [torch.tensor]: A sparse fwt analysis matrix.
+        torch.tensor: A sparse fwt analysis matrix.
 
     Note:
         The construced matrix is NOT necessary orthogonal.
@@ -53,8 +55,8 @@ def _construct_a_2d(wavelet, height: int, width: int,
     return analysis
 
 
-def _construct_s_2d(wavelet, height: int, width: int,
-                    device, dtype=torch.float64) -> torch.tensor:
+def _construct_s_2d(wavelet: pywt.Wavelet, height: int, width: int,
+                    device: torch.device, dtype=torch.float64) -> torch.tensor:
     """Construct a raw fast wavelet transformation synthesis matrix.
 
     Note:
@@ -120,7 +122,7 @@ def construct_boundary_a2d(
             Defaults to torch.float64.
 
     Returns:
-        [torch.Tensor]: A sparse fwt matrix, with orthogonalized boundary
+        torch.Tensor: A sparse fwt matrix, with orthogonalized boundary
             wavelets.
     """
     a = _construct_a_2d(
@@ -135,7 +137,7 @@ def construct_boundary_s2d(
         device: torch.device,
         boundary: str = 'qr',
         dtype=torch.float64) -> torch.Tensor:
-    """Construct a 2d-fwt matrix, with boundary wavelets.
+    """ Construct a 2d-fwt matrix, with boundary wavelets.
 
     Args:
         wavelet: A pywt wavelet.
@@ -162,7 +164,13 @@ def construct_boundary_s2d(
 
 
 class MatrixWavedec2d(object):
-    """Sparse matrix 2d wavelet transform.
+    """ Experimental sparse matrix 2d wavelet transform.
+
+       Input images are expected to be divisible by two.
+       For multiscale transforms all intermediate
+       scale dimensions must be divisible
+       by two, i.e. 128, 128 -> 64, 64 -> 32, 32 would work
+       for a level three transform.
 
     Note:
         Constructing the sparse fwt-matrix is expensive.
@@ -182,7 +190,7 @@ class MatrixWavedec2d(object):
 
     """
 
-    def __init__(self, wavelet, level: int,
+    def __init__(self, wavelet: pywt.Wavelet, level: int,
                  boundary: str = 'qr'):
         """Create a new matrix fwt object.
 
@@ -264,6 +272,10 @@ class MatrixWavedec2d(object):
                 current_height, current_width = size_list[-1]
                 if current_height < filt_len or current_width < filt_len:
                     break
+                assert current_height % 2  == 0, \
+                    "Image height must be divisible by two on all scales."
+                assert current_height % 2  == 0, \
+                    "Image width must be divisible by two on all scales."
                 analysis_matrix_2d = construct_boundary_a2d(
                     self.wavelet, current_height, current_width,
                     dtype=input_signal.dtype, device=input_signal.device,
@@ -320,7 +332,7 @@ class MatrixWaverec2d(object):
         >>> reconstruction = matrixifwt(mat_coeff)
     """
 
-    def __init__(self, wavelet, boundary: str = 'qr'):
+    def __init__(self, wavelet: pywt.Wavelet, boundary: str = 'qr'):
         """Create the inverse matrix based fast wavelet transformation.
 
         Args:
